@@ -38,7 +38,7 @@ def t():
     'in_u_and_v_different_values': {'u': {'d': 2}, 'v': {'d': 3}}
   }
   z = f(u, v)
-  if y != z: return pf([
+  return y == z or pf([
     'y != z',
     f"y['u_only']: {y['u_only']}",
     f"z['u_only']: {z['u_only']}",
@@ -46,4 +46,3 @@ def t():
     f"y['v_only']: {y['v_only']}",
     f"z['v_only']: {z['v_only']}",
   ])
-  return True
