@@ -3,10 +3,7 @@ def f(a, b):
   for k_b in b:
     if k_b in d_ab:
       for k in b[k_b]:
-        if k in d_ab[k_b]:
-          d_ab[k_b][k] += b[k_b][k]
-        else:
-          d_ab[k_b][k] = b[k_b][k]
+        d_ab[k_b][k] = d_ab[k_b][k] + b[k_b][k] if k in d_ab[k_b] else b[k_b][k]
     else:
       d_ab[k_b] = b[k_b]
   return d_ab
@@ -24,4 +21,4 @@ def t():
       'ba': {'a': 1, 'b': 2, '!': 3},
     },
     f(d3, d4) == {'aa': {'c': 2}, 'aa': {'c': 2, 'd': 1}},
-  ])
\ No newline at end of file
+  ])
