@@ -6,11 +6,11 @@ f = lambda directories: all([directory_exists(d) for d in directories])
 
 root = './temp'
 directories = [f'{root}/{directory}' for directory in ['abc', 'ghi', 'jkl']]
-setup = lambda: [mkdirine(d) for d in [root, *directories]]
-tear_down = lambda: rmdir(root)
+up = lambda: [mkdirine(d) for d in [root, *directories]]
+dn = lambda: rmdir(root)
 
 def t():
-  setup()
+  up()
   expected_pass = f(directories)
 
   rmdir(root)
@@ -18,5 +18,5 @@ def t():
 
   result = all([expected_pass, not expected_fail])
 
-  tear_down()
+  dn()
   return result
