@@ -5,14 +5,14 @@ from os.path import exists
 temp_root = './_dist_tars_remove'
 temp_L = list('abc')
 
-def setup(): mkdirine(temp_root)
-def tear_down(): rmdirie(temp_root)
+def up(): mkdirine(temp_root)
+def dn(): rmdirie(temp_root)
 
 def t():
-  setup()
+  up()
   f(temp_L, temp_root)
-  passed = all([exists(f'{temp_root}/{_l}') for _l in temp_L])
-  tear_down()
-  return passed
+  result = all([exists(f'{temp_root}/{_l}') for _l in temp_L])
+  dn()
+  return result
 
-def f(_L, root='.'): [mkdirine(f'{temp_root}/{_l}') for _l in temp_L]
\ No newline at end of file
+def f(_L, root='.'): [mkdirine(f'{temp_root}/{_l}') for _l in temp_L]
