@@ -6,15 +6,15 @@ from os import listdir
 from jft.file.remove import f as remove
 
 r = './temp'
-setup = lambda: [mkdir(r), *[save(f'{r}/{_}.txt', _) for _ in az]]
-tear_down = lambda: rmdir(r)
+up = lambda: [mkdir(r), *[save(f'{r}/{_}.txt', _) for _ in az]]
+dn = lambda: rmdir(r)
 f = lambda x: [remove(f'{r}/{filename}') for filename in listdir(x)]
 
 def t():
-  setup()
+  up()
   α = len(listdir(r))
   f(r)
   ω = len(listdir(r))
   result = all([α>ω, ω==0])
-  tear_down()
+  dn()
   return result
