@@ -9,19 +9,18 @@ _dir = './_directory_is_module'
 _dir_expected_true = f'{_dir}/_expected_true'
 _dir_expected_false = f'{_dir}/_expected_false'
 
-def setup():
+def up():
   mkdirine(_dir)
   mkdirine(_dir_expected_true)
   save(f'{_dir_expected_true}/__init__.py', '')
   mkdirine(_dir_expected_false)
 
-def tear_down(): rmdirie(_dir)
+def dn(): rmdirie(_dir)
 
-def f(x):
-  return all([exists(x), isdir(x), exists(f'{x}/__init__.py')])
+f = lambda x: all([exists(x), isdir(x), exists(f'{x}/__init__.py')])
 
 def t():
-  setup()
-  passed = all([f(_dir_expected_true), not f(_dir_expected_false)])
-  tear_down()
-  return passed
\ No newline at end of file
+  up()
+  result = all([f(_dir_expected_true), not f(_dir_expected_false)])
+  dn()
+  return result
