@@ -9,26 +9,23 @@ from os.path import exists
 
 f = lambda root, filepaths=[]: list_filepaths(root, filepaths, is_pyfile)
 
-temp_dir_0 = './_list_pyfilepaths'
-temp_dir_1 = f'{temp_dir_0}/_'
+dir_a = './_list_pyfilepaths'
+dir_b = f'{dir_a}/_'
 temp_files_and_content = [
-  (f'{temp_dir_0}/foo.py', 'foo'), (f'{temp_dir_0}/xyz.txt', 'xyz'),
-  (f'{temp_dir_1}/abc.txt', 'abc'), (f'{temp_dir_1}/bar.py', 'bar'),
+  (f'{dir_a}/foo.py', 'foo'), (f'{dir_a}/xyz.txt', 'xyz'),
+  (f'{dir_b}/abc.txt', 'abc'), (f'{dir_b}/bar.py', 'bar'),
 ]
 
-def setup():
-  [(nopx if exists(δ) else mkdir)(δ) for δ in [temp_dir_0, temp_dir_1]]
+def up():
+  [(nopx if exists(δ) else mkdir)(δ) for δ in [dir_a, dir_b]]
   [save(filename, content) for (filename, content) in temp_files_and_content]
 
-def tear_down():
+def dn():
   [remove(filename) for (filename, _) in temp_files_and_content]
-  [remove_dir(d) for d in [temp_dir_1, temp_dir_0]]
+  [remove_dir(d) for d in [dir_b, dir_a]]
 
 def t():
-  setup()
-  test_result = set([
-    f'{temp_dir_1}/bar.py',
-    f'{temp_dir_0}/foo.py'
-  ]) == set(f(temp_dir_0, []))
-  tear_down()
-  return test_result
+  up()
+  result = set([f'{dir_b}/bar.py', f'{dir_a}/foo.py']) == set(f(dir_a, []))
+  dn()
+  return result
