@@ -4,6 +4,7 @@ from jft.file.save import f as save
 from os import remove
 from jft.directory.remove import f as remove_dir
 from os.path import exists
+from jft.pf import f as pf
 
 _f = lambda root='.': [
   φ for φ in list_py_files(root, [])
@@ -55,27 +56,18 @@ temp_files_and_content = [
   (f'{temp_dir_1}/bar.py', 'f = lambda: None\nt = lambda: True'),
 ]
 
-def setup():
+def up():
   [mkdir(temp_dir) for temp_dir in [temp_dir_0, temp_dir_1]]
   [save(filename, content) for (filename, content) in temp_files_and_content]
 
-def tear_down():
+def dn():
   [remove(filename) for (filename, _) in temp_files_and_content]
   remove_dir(temp_dir_1)
   remove_dir(temp_dir_0)
 
 def t():
-  setup()
-  expectation = set([
-    './_/_/bar.py',
-    './_/foo.py'
-  ])
-  observation = set(f(temp_dir_0))
-  test_result = expectation == observation
-  tear_down()
-
-  if not test_result:
-    print(f'expectation: {expectation}')
-    print(f'observation: {observation}')
-
-  return test_result
\ No newline at end of file
+  up()
+  y = set(['./_/_/bar.py', './_/foo.py'])
+  z = set(f(temp_dir_0))
+  dn()
+  return y == z or pf([f'y: {y}', f'z: {z}'])
