@@ -1,11 +1,8 @@
 class FakePrinter:
   def __init__(self):
     self.history = []
-
   __call__ = lambda self, x: self.history.append(x)
-
-  def reset(self):
-    self.history = []
+  def reset(self): self.history = []
 
 f = lambda: FakePrinter()
 
@@ -22,4 +19,4 @@ def t():
   fp.reset()
   if fp.history != []: return False
 
-  return True
\ No newline at end of file
+  return True
