@@ -3,7 +3,6 @@ from jft.file.load import f as load
 from jft.file.remove import f as remove
 from jft.file.decrypt import f as decrypt
 from subprocess import run
-from os.path import exists
 
 _content = "Dyson Sphere\n"
 _in_filename = "./_test_file_encrypt_in.txt"
@@ -23,20 +22,20 @@ def f(in_filename, out_filename, password): run(
   capture_output=True
 )
 
-def setup():
-  tear_down()
+def up():
+  dn()
   save(_in_filename, _content)
 
-def tear_down():
+def dn():
   remove(_in_filename)
   remove(_enc_filename)
   remove(_out_filename)
 
 def t():
-  setup()
+  up()
   f(_in_filename, _enc_filename, _password)
   decrypt(_enc_filename, _out_filename, _password)
-  observation = load(_out_filename)
-  passed = observation == _content
-  tear_down()
-  return passed
+  z = load(_out_filename)
+  result = z == _content
+  dn()
+  return result
