@@ -11,16 +11,16 @@ def f(filename):
 temp_dir_0 = './_temp_file_load'
 temp_files_and_content = [(f'{temp_dir_0}/foo.py', 'foo')]
 
-def setup():
+def up():
   [mkdir(temp_dir) for temp_dir in [temp_dir_0] if not exists(temp_dir)]
   [save(filename, content) for (filename, content) in temp_files_and_content]
 
-def tear_down():
+def dn():
   [remove(filename) for (filename, _) in temp_files_and_content]
   remove_dir(temp_dir_0)
 
 def t():
-  setup()
+  up()
   test_result = 'foo' == f(f'{temp_dir_0}/foo.py')
-  tear_down()
-  return test_result
\ No newline at end of file
+  dn()
+  return test_result
