@@ -4,22 +4,16 @@ from jft.file.load import f as load
 from jft.file.remove import f as remove
 from jft.file.save import f as save
 
+f = lambda filename, data: save(filename, data)
 _dirname = './temp'
 _filename = f'{_dirname}/foo.py'
 _data = '\n'.join(["f = lambda: None", "t = lambda: False", ""])
-
-setup = lambda: mkdirine(_dirname)
-tear_down = lambda: [remove(_filename), rmdir(_dirname)]
-  
+up = lambda: mkdirine(_dirname)
+dn = lambda: [remove(_filename), rmdir(_dirname)]
 def t():
-  setup()
+  up()
+  y = _data
   f(_filename, _data)
-  observation = load(_filename)
-  expectation = _data
-  tear_down()
-  return observation == expectation
-
-def f(filename, data):
-  return save(filename, data)
-
-if __name__ == '__main__': f()
+  z = load(_filename)
+  dn()
+  return y == z
