@@ -1,6 +1,5 @@
 from jft.file.load import f as load
-from jft.string.separate_function_from_context import f as separate_function_from_content
-
+from jft.string.separate_function_from_context import f as part_f_from_content
 from jft.directory.make import f as mkdir
 from jft.directory.remove import f as rmdir
 from jft.string.split_fn_name_and_text import f as split_function_name_and_text
@@ -18,17 +17,13 @@ def f(_pi_filename, root='.', silent=True):
   (
     initial_function_text,
     initial_other_text
-  ) = separate_function_from_content(initial_content)
+  ) = part_f_from_content(initial_content)
 
-
-  if not initial_function_text:
-    return
+  if not initial_function_text: return
 
   f_name, f_body = split_function_name_and_text(initial_function_text)
 
-  if function_is_ignorable(f_name):
-    return f_name
-
+  if function_is_ignorable(f_name): return f_name
 
   new_content = prepend_import(f_name, initial_other_text)
   new_function_text = 'def f'+f_body
@@ -52,7 +47,7 @@ def f(_pi_filename, root='.', silent=True):
 _root = '../temp_pyfile_dismantle'
 _pi_filename = _root+'/foo.py'
 
-def setup(): return [
+up = lambda: [
   mkdir(_root),
   save(_pi_filename, '\n'.join([
     '# Header comment',
@@ -69,17 +64,15 @@ def setup(): return [
   ]))
 ]
 
-def tear_down(): return [rmdir(_root)]
+dn = lambda: rmdir(_root)
 
 def t():
-  setup()
+  up()
   original_file_content = load(_pi_filename)
-
-  z = f(_pi_filename, _root, silent=True)
-
+  f(_pi_filename, _root, silent=True)
   extracted_file_content = load( _root+'/_foo.py')
   updated_file_content = load(_pi_filename)
-  tear_down()
+  dn()
   return all([
     original_file_content != updated_file_content,
     extracted_file_content == '\n'.join([
@@ -100,4 +93,4 @@ def t():
       '  print(foo(goo(1, 2), 3, 4))',
       ''
     ])
-  ])
\ No newline at end of file
+  ])
