@@ -1,3 +1,4 @@
+# ignore_overlength_lines
 from jft.string.remove.empty_lines import f as remove_empty_lines
 from jft.text_colours.tgfr import f as tgfr
 
@@ -6,12 +7,9 @@ def f(content):
   first_colon_following_first_def = content.find(':', first_def)
   second_def = content.find('def ', first_colon_following_first_def)
   _if_name_main = content.find("if __name__ == '__main__':")
-  if first_def < 0:
-    return ('', content)
-  if second_def < 0:
-    second_def = len(content)
-  if _if_name_main < 0:
-    _if_name_main = len(content)
+  if first_def < 0: return ('', content)
+  if second_def < 0: second_def = len(content)
+  if _if_name_main < 0: _if_name_main = len(content)
   _min = min(second_def, _if_name_main)
   function_text = content[first_def: _min]
   other_text = remove_empty_lines(content[:first_def] + content[_min:])
@@ -57,7 +55,7 @@ _content = '\n'.join([
   "  overwrite_existing_py_file(_pi_filename, new_content)",
 ])
 
-_expectation_left = '\n'.join([
+_y_left = '\n'.join([
   "def default_equality_operator(y, z):",
   "  return y==z",
   "  # default_equality_operator = lambda y, z: y==z",
@@ -65,7 +63,7 @@ _expectation_left = '\n'.join([
   "",
 ])
 
-_expectation_right = '\n'.join([
+_y_right = '\n'.join([
   "from x import run as x",
   "",
   "def f(_pi_filename):",
@@ -102,25 +100,22 @@ _expectation_right = '\n'.join([
 ])
 
 def t():
-  observation_left, observation_right = f(_content)
-  return all([
-    observation_left == _expectation_left,
-    observation_right == _expectation_right,
-  ])
+  z_left, z_right = f(_content)
+  return all([z_left == _y_left, z_right == _y_right])
 
 if __name__ == '__main__':
-  print(f'Test passed: {tgfr(t())}')
+  print(f'Test result: {tgfr(t())}')
   print('-'*18)
-  observation_left, observation_right= f(_content)
-  print(f'observation_left == expectation_left: {tgfr(observation_left == _expectation_left)}')
-  if not observation_left == _expectation_left:
-    observation_left_lines = observation_left.split('\n')
-    expectation_left_lines = _expectation_left.split('\n')
-    for index in range(len(observation_left_lines)):
-      l = expectation_left_lines[index]
-      r = observation_left_lines[index]
+  z_left, z_right= f(_content)
+  print(f'z_left == y_left: {tgfr(z_left == _y_left)}')
+  if not z_left == _y_left:
+    z_left_lines = z_left.split('\n')
+    y_left_lines = _y_left.split('\n')
+    for index in range(len(z_left_lines)):
+      l = y_left_lines[index]
+      r = z_left_lines[index]
       if l != r:
         print(l)
         print(r)
         print()
-  print(f'observation_right == expectation_right: {tgfr(observation_right == _expectation_right)}')
+  print(f'z_right == y_right: {tgfr(z_right == _y_right)}')
