@@ -3,6 +3,7 @@ from os import remove
 from os import mkdir
 from jft.nop_x import f as nopx
 from os import rmdir
+from jft.pf import f as pf
 
 def f(filepath, content):
   with open(filepath, 'w') as φ:
@@ -12,36 +13,33 @@ def f(filepath, content):
 _root = './temp_save_string'
 _filepath = f'{_root}/temp.txt'
 
-setup = lambda: (mkdir if not exists(_root) else nopx)(_root)
+up = lambda: (mkdir if not exists(_root) else nopx)(_root)
 
-def tear_down():
+def dn():
   if exists(_filepath):
     remove(_filepath)
   rmdir(_root)
 
 def t():
-  setup()
+  up()
   
-  input_content = 'apple'
-  result = f(_filepath, input_content)
+  x_content = 'apple'
+  result = f(_filepath, x_content)
 
   if not exists(_filepath):
-    print(f'{_filepath} file was not created by file.write.run()')
-    tear_down()
-    return False
+    dn()
+    return pf(f'{_filepath} file was not created by file.write.run()')
 
   with open(_filepath, 'r') as _file:
     file_content = _file.read()
 
-  if file_content != input_content:
-    print(f'{file_content} != {input_content}')
-    tear_down()
-    return False
+  if file_content != x_content:
+    dn()
+    return pf(f'{file_content} != {x_content}')
 
-  if result != input_content:
-    print(f'{result} != {input_content}')
-    tear_down()
-    return False
+  if result != x_content:
+    dn()
+    return pf(f'{result} != {x_content}')
 
-  tear_down()
+  dn()
   return True
