@@ -8,18 +8,16 @@ from jft.string.has_lowercase import f as has_lowercase
 filename = 'username.secret'
 
 def f(root='.'):
-  _ = f'{root}/{filename}'
-  with open(_, 'r') as φ:
-    return φ.readlines()[0]
+  with open(f'{root}/{filename}', 'r') as φ: return φ.readlines()[0]
 
 _root = '../temp_secret_username'
 _filepath = f'{_root}/{filename}'
-
-setup = lambda: [mkdirine(_root), save(_filepath, 'z3525170@ad.unsw.edu.au')]
-
-tear_down = lambda: rmdirie(_root)
+up = lambda: [mkdirine(_root), save(_filepath, 'z3525170@ad.unsw.edu.au')]
+dn = lambda: rmdirie(_root)
 
 def t():
-  setup()
+  up()
   z = f(_root)
-  return all([has_7_digits(z), has_at_symbol(z), has_lowercase(z)])
+  result = all([has_7_digits(z), has_at_symbol(z), has_lowercase(z)])
+  dn()
+  return result
