@@ -18,32 +18,31 @@ data = (
 _dir_name = './_test_tar_extract'
 _archive_filename = f"compressed.tar.gz"
 _archive_name = f'{_dir_name}/{_archive_filename}'
-_expectation_dir_0 = f"{_dir_name}/_test_directory_compress_to_tar"
-_expectation_dir_1 = f"{_expectation_dir_0}/source"
+_y_dir_0 = f"{_dir_name}/_test_directory_compress_to_tar"
+_y_dir_1 = f"{_y_dir_0}/source"
 
 
-def setup():
-  tear_down()
+def up():
+  dn()
   mkdirine(_dir_name)
   with open(_archive_name, 'wb') as _file:
     _file.write(data)
 
-def f(archive_filename, dir_name='.'):
-  return run(
-    args=f"tar -xvzf {archive_filename} -C {dir_name}".split(),
-    capture_output=True
-  )
+def f(archive_filename, dir_name='.'): run(
+  args=f"tar -xvzf {archive_filename} -C {dir_name}".split(),
+  capture_output=True
+)
 
-def tear_down():
+def dn():
   rmdirie(_dir_name)
-  rmdirie(_expectation_dir_0)
+  rmdirie(_y_dir_0)
 
 def t():
-  setup()
+  up()
   f(_archive_name, _dir_name)
-  passed = all([
-    load(f"{_expectation_dir_1}/a.txt") == '_source_file_a_path',
-    load(f"{_expectation_dir_1}/b.txt") == '_source_file_b_path'
+  result = all([
+    load(f"{_y_dir_1}/a.txt") == '_source_file_a_path',
+    load(f"{_y_dir_1}/b.txt") == '_source_file_b_path'
   ])
-  tear_down()
-  return passed
+  dn()
+  return result
