@@ -36,22 +36,22 @@ _Pi_content = {k: '\n'.join([
   for k in K
 }
 
-def setup(): return [
+def up(): return [
   mkdir(_root),
   *[save(_Pi_path_original[k], _Pi_content[k]) for k in K]
 ]
 
-tear_down = lambda: rmdir(_root)
+dn = lambda: rmdir(_root)
 
 def t():
-  setup()
+  up()
 
   _Pi_original_content = {k: load(_Pi_path_original[k]) for k in K}
   z = f(_root)
   _Pi_observed_updated = {k: load(_Pi_path_original[k]) for k in K}
   _Pi_observed_new = {k: load(_Pi_path_new[k]) for k in K}
   
-  tear_down()
+  dn()
 
   return all([
     _Pi_original_content != _Pi_observed_updated,
