@@ -5,5 +5,4 @@ def f(x):
   if isinstance(x, str): return x
   return None if isnan(x) else x
 
-def t():
-  return f(nan) == None
+t = lambda: f(nan) == None
