@@ -26,17 +26,17 @@ content = "\n".join([
 ])
 version={'major': 1, 'minor': 2, 'patch': 3}
 
-def setup(): save(filename, content)
+def up(): save(filename, content)
 
-def tear_down(): remove(filename)
+def dn(): remove(filename)
 
 def t():
-  setup()
+  up()
   f(version, filename)
   lines = read_file(filename).split('\n')
   version_line = [l for l in lines if l.startswith('  version=')][0]
   version_str = eval(version_line.strip()[:-1].split('=')[1])
   major, minor, patch = [int(_) for _ in version_str.split('.')]
   result = {'major': major, 'minor': minor, 'patch': patch} == version
-  tear_down()
+  dn()
   return result
