@@ -6,8 +6,8 @@ from jft.file.load import f as load
 
 _dir = '../start_upload'
 
-def setup(): return mkdirine(_dir)
-def tear_down(): return rmdirie(_dir)
+def up(): return mkdirine(_dir)
+def dn(): return rmdirie(_dir)
 
 _username = load('username.secret')
 _password = load('password.secret')
@@ -20,18 +20,18 @@ def f(sprun=sprun, cwd='.', capture_output=True):
   )
 
 def t():
-  setup()
-  observation = f(fake_sprun, cwd=_dir)
+  up()
+  z = f(fake_sprun, cwd=_dir)
   result = all([
-    _password in observation.args,
-    _username in observation.args,
-    'twine' in observation.args,
-    'upload' in observation.args,
-    'dist/*' in observation.args,
-    '-u' in observation.args,
-    '-p' in observation.args,
-    observation.returncode == 0,
-    'Uploading distributions to https://upload.pypi.org' in observation.stdout.decode()
+    _password in z.args,
+    _username in z.args,
+    'twine' in z.args,
+    'upload' in z.args,
+    'dist/*' in z.args,
+    '-u' in z.args,
+    '-p' in z.args,
+    z.returncode == 0,
+    'Uploading distributions to https://upload.pypi.org' in z.stdout.decode()
   ])
-  tear_down()
+  dn()
   return result
