@@ -13,18 +13,16 @@ f = lambda name, time_started, max_filename_length: (
 )
 
 def t():
-  e_result = True
-  e_message_l = '|'.join([
+  y_result = True
+  y_message_l = '|'.join([
     '\r|\x1b[1;32m  PASS  \x1b[0;0m',
     ' fake_name ',
     ' \x1b[1;32m                           '
   ])
-  e_message_r = '\x1b[0;0m |'
-
-  o_result, o_message = f('fake_name', time(), 9)
-
+  y_message_r = '\x1b[0;0m |'
+  z_result, z_message = f('fake_name', time(), 9)
   return all([
-    e_result == o_result,
-    e_message_l == o_message[0:len(e_message_l)],
-    e_message_r == o_message[len(o_message) - len(e_message_r):]
+    y_result == z_result,
+    y_message_l == z_message[0:len(y_message_l)],
+    y_message_r == z_message[len(z_message) - len(y_message_r):]
   ])
