@@ -7,7 +7,7 @@ from jft.directory.remove import f as rmdirie
 temp_dir_path = temp_dir_path = './_setup_cfg_update'
 temp_file_path = f'{temp_dir_path}/setup.cfg'
 
-def setup():
+def up():
   mkdirine(temp_dir_path)
   save(temp_file_path, "\n".join([
     "[metadata]",
@@ -31,8 +31,7 @@ def setup():
     "include_package_data = True",
   ]))
 
-def tear_down():
-  rmdirie(temp_dir_path)
+dn = lambda: rmdirie(temp_dir_path)
 
 def f(v, filename='setup.cfg'):
   lines = load(filename).split('\n')
@@ -41,9 +40,8 @@ def f(v, filename='setup.cfg'):
   return None
 
 def t():
-  setup()
+  up()
   f(v={'major': 4, 'minor': 5, 'patch': 6}, filename=temp_file_path)
-  observation = load(temp_file_path)
-  test_passed = "version = 4.5.6" in observation
-  tear_down()
-  return test_passed
+  z = load(temp_file_path)
+  dn()
+  return "version = 4.5.6" in z
