@@ -3,11 +3,12 @@ from jft.file.save import f as save
 from jft.strings.patch_setup_py import f as increment_patch_in_setup_py
 from jft.directory.make import f as mkdirine
 from jft.directory.remove import f as rmdirie
+from jft.pf import f as pf
 
 temp_dir_path = temp_dir_path = './_setup_py_update'
 temp_file_path = f'{temp_dir_path}/setup.py'
 
-def setup():
+def up():
   mkdirine(temp_dir_path)
   save(temp_file_path, "\n".join([
     "from setuptools import setup",
@@ -30,7 +31,7 @@ def setup():
     ")",
   ]))
 
-def tear_down(): rmdirie(temp_dir_path)
+dn = lambda: rmdirie(temp_dir_path)
 
 def f(v, filename='setup.py'):
   lines = load(filename).split('\n')
@@ -39,14 +40,9 @@ def f(v, filename='setup.py'):
   return None
 
 def t():
-  setup()
+  up()
+  y = "version='4.5.6',"
   f(v={'major': 4, 'minor': 5, 'patch': 6}, filename=temp_file_path)
-  observation = load(temp_file_path)
-  expectation = "version='4.5.6',"
-  test_passed = expectation in observation
-  if not test_passed:
-    print(f'expectation: {expectation}')
-    print(f'observation: {observation}')
-
-  tear_down()
-  return test_passed
+  z = load(temp_file_path)
+  dn()
+  return y in z or pf([f'y: {y}', f'z: {z}'])
