@@ -5,21 +5,14 @@ from jft.string.char.is_upper import f as is_upper
 f = lambda ζ: (
   ('_' if is_digit(ζ[0]) else '')+ ζ[0].lower() + ''.join([
     f'_{ζ[θ].lower()}' if all([
-      any([
-        is_upper(ζ[θ]),
-        is_digit(ζ[θ]),
-        is_digit(ζ[θ-1]),
-      ]),
-      not all([
-        is_digit(ζ[θ]),
-        is_digit(ζ[θ-1]),
-      ])
+      any([is_upper(ζ[θ]), is_digit(ζ[θ]), is_digit(ζ[θ-1])]),
+      not all([is_digit(ζ[θ]), is_digit(ζ[θ-1])])
     ]) else f'{ζ[θ].lower()}'
     for θ in range(1, len(ζ))
   ])
 )
 
 def t():
-  observation = f("ThisIsAnExampleOfCamelCase")
-  expectation = "this_is_an_example_of_camel_case"
-  return observation == expectation
+  z = f("ThisIsAnExampleOfCamelCase")
+  y = "this_is_an_example_of_camel_case"
+  return y == z
