@@ -7,25 +7,16 @@ def f(original):
   _L = prepare_combinations(chars)
   for _l in _L:
     candidate_data = data.replace(_l, '')
-
     if len(candidate_data) < len(data):
       _raw_result = sprun(
         args=[ 'python3', '-c', candidate_data],
         capture_output=True
       )
-
-      # print(f'_raw_result: {_raw_result}')
       _decoded_stdout = _raw_result.stdout.decode()
-      # print(f'_decoded_stdout: {_decoded_stdout}')
       if len(_decoded_stdout) > 0:
-        try:
-          result = eval(_decoded_stdout)
-        except SyntaxError as se:
-          result = False
-
-        if result:
-          data = candidate_data
-
+        try: result = eval(_decoded_stdout)
+        except SyntaxError as se: result = False
+        if result: data = candidate_data
   return len(original)>len(data), data
 
 def t():
@@ -34,9 +25,9 @@ def t():
     "  return x*x",
     "",
     "def test():",
-    "  expectation = 16",
-    "  observation = foo(4)",
-    "  return observation == expectation",
+    "  y = 16",
+    "  z = foo(4)",
+    "  return y == z",
     "",
     "if __name__=='__main__':print(test())",
   ])
@@ -46,11 +37,11 @@ def t():
     "  return x*x",
     "",
     "def tt():",
-    "  pon = 16",
-    "  n = o(4)",
-    "  return n == pon",
+    "  y = 16",
+    "  z = o(4)",
+    "  return y == z",
     "",
     "if __name__=='__main__':print(tt())",
   ])])
 
-if __name__=='__main__': print(t())
\ No newline at end of file
+if __name__=='__main__': print(t())
