@@ -1,17 +1,15 @@
+# ignore_overlength_lines
 from jft.string.remove.empty_lines import f as remove_empty_lines
 
 def f(content):
   first_def = content.find('def ')
-  if first_def < 0:
-    return ('', content)
+  if first_def < 0: return ('', content)
 
   second_def = content.find('def ', first_def+1)
-  if second_def < 0:
-    second_def = len(content)
+  if second_def < 0: second_def = len(content)
 
   _if_name_main = content.find("if __name__ == '__main__':")
-  if _if_name_main < 0:
-    _if_name_main = len(content)
+  if _if_name_main < 0: _if_name_main = len(content)
 
   _min = min(second_def, _if_name_main)
 
