@@ -7,8 +7,5 @@ def f(x):
   return d
 
 t = lambda: f('James!') == {
-  'Ja': {'m': 1},
-  'am': {'e': 1},
-  'me': {'s': 1},
-  'es': {'!': 1}
-}
\ No newline at end of file
+  'Ja': {'m': 1}, 'am': {'e': 1}, 'me': {'s': 1}, 'es': {'!': 1}
+}
