@@ -1,5 +1,6 @@
 from jft.strings.contain.version import f as k
 from jft.pip.version.to_str import f as make_v_str
+from jft.pf import f as pf
 
 def _k(x): return 'jft/pip/version' not in x
 
@@ -10,14 +11,11 @@ f = lambda v, _L: [
 v = {'major': 4, 'minor': 5, 'patch': 6}
 
 def t():
-  for (expectation, observation) in [
+  for (y, z) in [
     ([], f({}, [])),
     ([], f(v, [])),
     (["  version='4.5.6',", '.'], f(v, ["  version='x.x.x',", '.'])),
     (['.', "  version='4.5.6',"], f(v, ['.', "  version='x.x.x',"])),
   ]:
-    if expectation != observation:
-      print(f'expectation: {expectation}')
-      print(f'observation: {observation}')
-      return False
-  return True
\ No newline at end of file
+    if y != z: return pf([f'y: {y}', f'z: {z}'])
+  return True
