@@ -23,12 +23,12 @@ f = lambda root='./': save(root + '.gitignore', data)
 
 if __name__ == '__main__': f()
 
-setup = lambda: mkdirine('./temp/')  
-tear_down = lambda: rmdir('./temp/')
+up = lambda: mkdirine('./temp/')  
+dn = lambda: rmdir('./temp/')
 
 def t():
-  setup()
+  up()
   f('./temp/')
   result = data==load('./temp/.gitignore')
-  tear_down()
+  dn()
   return result
