@@ -7,21 +7,21 @@ from jft.system.git.commit.run import f as git_commit
 
 _root = '../temp_git_log_oneline'
 
-def setup():
+def up():
   mkdir(_root)
   git_init(_root)
   save(_root+'/foo.py', 'foo')
   git_commit(do_pull=False, cwd=_root, do_push=False)
 
-def tear_down(): rmdir(_root)
+def dn(): rmdir(_root)
 
 args = ['git', 'log', '--oneline']
 
 f = lambda cwd: sprun(cwd=cwd, capture_output=True, args=args)
 def t():
-  setup()
+  up()
   z = f(_root)
-  tear_down()
+  dn()
   return all([
     z.args==args,
     z.returncode==0,
