@@ -9,8 +9,8 @@ from jft.pickle.load_if_exists import f as load_pickle
 _dir = './_handle_fail'
 _failed_pickle_path = f'{_dir}/failed.pickle'
 
-def setup(): mkdirine(_dir)
-def tear_down(): rmdirie(_dir)
+def up(): mkdirine(_dir)
+def dn(): rmdirie(_dir)
 
 def f(_Pi_failed, _pi, message, dt_now=None, root='.'):
   dt_now = dt_now or dt.now()
@@ -19,27 +19,15 @@ def f(_Pi_failed, _pi, message, dt_now=None, root='.'):
   return False, f"{danger('FAIL')} {warn(_pi)} {message} {dt_now}"
 
 def t():
-  setup()
-  observation = f(
-    set(['failed.py']),
-    'foo.py',
-    'foo foo',
-    dt(2022, 1, 1),
-    _dir
-  )
-
-  expectation = (
+  up()
+  y = (
     False,
     ' '.join([
       '\x1b[1;31mFAIL\x1b[0;0m \x1b[0;33mfoo.py\x1b[0;0m foo foo',
       '2022-01-01 00:00:00'
     ])
   )
-  observation_failed_pickle = load_pickle(_failed_pickle_path)
-
-  passed = all([
-    observation == expectation,
-    observation_failed_pickle == {'failed.py', 'foo.py'}
-  ])
-  tear_down()
-  return passed
\ No newline at end of file
+  z = f(set(['failed.py']), 'foo.py', 'foo foo', dt(2022, 1, 1), _dir)
+  z_failed_pickle = load_pickle(_failed_pickle_path)
+  dn()
+  return all([z == y, z_failed_pickle == {'failed.py', 'foo.py'}])
