@@ -5,10 +5,5 @@ t = lambda: all([
   f(('a', 'b')),
   f(('a', None)),
   f((1, 2)),
-  not any([f(_) for _ in [
-    0,
-    1.5,
-    [],
-    ''
-  ]])
-])
\ No newline at end of file
+  not any([f(_) for _ in [0, 1.5, [], '']])
+])
